@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of Radicale Server - Calendar Server
-# Copyright © 2008-2011 Guillaume Ayoub
+# Copyright © 2008-2012 Guillaume Ayoub
 # Copyright © 2008 Nicolas Kandel
 # Copyright © 2008 Pascal Halter
 #
@@ -44,7 +44,8 @@ INITIAL_CONFIG = {
         "pid": "",
         "ssl": "False",
         "certificate": "/etc/radicale/server.crt",
-        "key": "/etc/radicale/private/server.key"},
+        "key": "/etc/radicale/private/server.key",
+        "dns_lookup": "True"},
     "encoding": {
         "request": "utf-8",
         "stock": "utf-8"},
@@ -57,10 +58,16 @@ INITIAL_CONFIG = {
         "ldap_url": "ldap://localhost:389/",
         "ldap_base": "ou=users,dc=example,dc=com",
         "ldap_attribute": "uid",
+        "ldap_filter": "",
         "ldap_binddn": "",
-        "ldap_password": ""},
+        "ldap_password": "",
+        "ldap_scope": "OneLevel",
+        "pam_group_membership": "",
+        "courier_socket": ""},
     "storage": {
-        "folder": "/var/db/radicale/calendars"},
+        "type": "filesystem",
+        "filesystem_folder": "/var/db/radicale/calendars",
+        "git_folder": "/var/db/radicale/calendars"},
     "logging": {
         "config": "/etc/radicale/logging",
         "debug": "False",
@@ -76,8 +83,8 @@ for section, values in INITIAL_CONFIG.items():
 
 _CONFIG_PARSER.read("/etc/radicale/config")
 _CONFIG_PARSER.read(os.path.expanduser("~/.config/radicale/config"))
-if 'RADICALE_CONFIG' in os.environ:
-    _CONFIG_PARSER.read(os.environ['RADICALE_CONFIG'])
+if "RADICALE_CONFIG" in os.environ:
+    _CONFIG_PARSER.read(os.environ["RADICALE_CONFIG"])
 
 # Wrap config module into ConfigParser instance
 sys.modules[__name__] = _CONFIG_PARSER
